QEP Modeling with Derivatives
===============================================

Here are some examples of QEP modeling with derivative information in QPyTorch.


QEPs with Derivatives
----------------------

Derivative information can be used by QEPs to accelerate Bayesian optimization, and solve PDEs.
See the `1D derivatives QEP example`_,  the `2D derivatives QEP example`_, and the `variational QEP with 2nd order derivatives`_ 
for examples on using QEPs with derivative information.

.. toctree::
   :glob:
   :maxdepth: 1
   :hidden:

   Simple_QEP_Regression_Derivative_Information_1d.ipynb
   Simple_QEP_Regression_Derivative_Information_2d.ipynb
   SVQEP_Regression_Derivative_Information_2d.ipynb


.. _1D derivatives QEP example:
  Simple_QEP_Regression_Derivative_Information_1d.ipynb

.. _2D derivatives QEP example:
  Simple_QEP_Regression_Derivative_Information_2d.ipynb

.. _variational QEP with 2nd order derivatives:
  SVQEP_Regression_Derivative_Information_2d.ipynb
